@@ -5,6 +5,7 @@ import json
 from sdc_helpers import decorators
 from sdc_helpers.query_helper import QueryHelper
 from sqlalchemy import and_
+from sqlalchemy.exc import InternalError
 from sqlalchemy.orm import with_expression
 from sdc_engine_helpers.models.subscription import Subscription
 
@@ -15,7 +16,7 @@ class EngineQueryHelper(QueryHelper):
     """
     # pylint: disable=singleton-comparison
 
-    @decorators.query_exception_handler()
+    @decorators.query_exception_handler(exceptions=(Exception, InternalError,))
     def get_engine_entity(
             self,
             *,
@@ -23,7 +24,8 @@ class EngineQueryHelper(QueryHelper):
             service_id: int,
             engine_slug: str,
             entity_key: str,
-            from_cache: bool = True
+            from_cache: bool = True,
+            for_update: bool = False
     ):
         """
             Get a specific entity from a specific engine in a subscription
@@ -34,6 +36,8 @@ class EngineQueryHelper(QueryHelper):
                 engine_slug (str): Subscription property engine
                 entity_key (str): The key of the entity in the engine
                 from_cache (bool): Retrieve the entities from cache - Default True
+                for_update (bool): Reserve the subscription for exclusive use until
+                                   commit or session is closed - Default False
 
             returns:
                 entity_list (list): A list of the requested entity in the specified engine
@@ -54,7 +58,7 @@ class EngineQueryHelper(QueryHelper):
                 not from_cache or
                 not entities_redis
         ):
-            subscription = self.session.query(Subscription).filter(
+            query = self.get_query(Subscription, for_update).filter(
                 and_(
                     Subscription.client_id == client_id,
                     Subscription.service_id == service_id,
@@ -74,7 +78,9 @@ class EngineQueryHelper(QueryHelper):
                         entity_key=entity_key
                     )
                 )
-            ).first()
+            )
+
+            subscription = query.first()
 
             entities = None
             if subscription is not None:
@@ -100,6 +106,7 @@ class EngineQueryHelper(QueryHelper):
             service_id: int,
             engine_slug: str,
             from_cache: bool = True,
+            for_update: bool = False,
             **kwargs
     ):
         """
@@ -110,6 +117,8 @@ class EngineQueryHelper(QueryHelper):
                 service_id (int): The service id of the subscription
                 engine_slug (str): Subscription property engine
                 from_cache (bool): Retrieve the datasets from cache - Default True
+                for_update (bool): Reserve the subscription for exclusive use until
+                                   commit or session is closed - Default False
                 kwargs (dict):
                     label (str): The dataset's label
 
@@ -123,7 +132,8 @@ class EngineQueryHelper(QueryHelper):
             service_id=service_id,
             engine_slug=engine_slug,
             entity_key='datasets',
-            from_cache=from_cache
+            from_cache=from_cache,
+            for_update=for_update
         )
 
         if datasets is not None:
@@ -140,6 +150,7 @@ class EngineQueryHelper(QueryHelper):
             service_id: int,
             engine_slug: str,
             from_cache: bool = True,
+            for_update: bool = False,
             **kwargs
     ):
         """
@@ -150,6 +161,8 @@ class EngineQueryHelper(QueryHelper):
                 service_id (int): The service id of the subscription
                 engine_slug (str): Subscription property engine
                 from_cache (bool): Retrieve the campaigns from cache - Default True
+                for_update (bool): Reserve the subscription for exclusive use until
+                                   commit or session is closed - Default False
                 kwargs (dict):
                     arn (str): The campaign's arn
                     recipe (str): The recipe of the campaign e.g related_items
@@ -164,7 +177,8 @@ class EngineQueryHelper(QueryHelper):
             service_id=service_id,
             engine_slug=engine_slug,
             entity_key='campaigns',
-            from_cache=from_cache
+            from_cache=from_cache,
+            for_update=for_update
         )
 
         if campaigns is not None:
@@ -179,6 +193,7 @@ class EngineQueryHelper(QueryHelper):
             service_id: int,
             engine_slug: str,
             from_cache: bool = True,
+            for_update: bool = False,
             **kwargs
     ):
         """
@@ -189,6 +204,8 @@ class EngineQueryHelper(QueryHelper):
                 service_id (int): The service id of the subscription
                 engine_slug (str): Subscription property engine
                 from_cache (bool): Retrieve the solutions from cache - Default True
+                for_update (bool): Reserve the subscription for exclusive use until
+                                   commit or session is closed - Default False
                 kwargs (dict):
                     arn (str): The campaign's arn
                     recipe (str): The recipe of the solution e.g related_items
@@ -203,7 +220,8 @@ class EngineQueryHelper(QueryHelper):
             service_id=service_id,
             engine_slug=engine_slug,
             entity_key='solutions',
-            from_cache=from_cache
+            from_cache=from_cache,
+            for_update=for_update
         )
 
         if solutions is not None:
