@@ -4,6 +4,8 @@
 from datetime import datetime
 from sdc_helpers.models.client import Client
 import boto3
+from sqlalchemy.exc import SQLAlchemyError
+from sdc_engine_helpers import decorators
 from sdc_engine_helpers.date_utils import DateUtils
 from sdc_engine_helpers.personalize.maintenance.campaign_state_manager import CampaignStateManager
 from sdc_engine_helpers.personalize.maintenance.solution_state_manager import SolutionStateManager
@@ -27,6 +29,7 @@ class MaintenanceManager(Manager):
         self.campaign_state_manager = CampaignStateManager()
         self.personalize = boto3.client('personalize')
 
+    @decorators.retry_handler(SQLAlchemyError, total_tries=3, initial_wait=2)
     def perform_maintenance(self):
         """
             Create new Personalize solution versions and update Personalize campaigns
@@ -41,7 +44,8 @@ class MaintenanceManager(Manager):
             subscription = self.query_helper.get_subscription(
                 client_id=client.id,
                 service_id=self.service.id,
-                from_cache=False
+                from_cache=False,
+                for_update=True
             )
 
             solutions, engine_index = self.query_helper.get_engine_entity(
@@ -89,7 +93,7 @@ class MaintenanceManager(Manager):
                     update = True
 
             if update:
-                self.query_helper.update_subscription(subscription=subscription)
+                self.query_helper.update(model=subscription)
                 self.query_helper.flush_subscription_properties_cache(subscription=subscription)
 
     def perform_solution_maintenance(self, *, client: Client, solutions: list) -> dict:
