@@ -33,6 +33,7 @@ class DatasetStateManager:
 
     """
     date_utils = DateUtils()
+    # slack_helper = SlackHelper()
     # vendor
     vendor_campaign_arn_path = 'EndpointName'
     vendor_campaign_status_path = 'EndpointStatus'
@@ -73,7 +74,7 @@ class DatasetStateManager:
             *,
             vendor_solution: dict,
             dataset_label: str,
-            filetype: str
+            file_type: str
         ) -> str:
         """
             Get a Sagemaker Training job input dataset by channel name
@@ -92,7 +93,7 @@ class DatasetStateManager:
                 channel_name = d_configs.get("ChannelName")
 
                 if channel_name is None:
-                    raise Exception("ChannelName must be provided by vendor")
+                    raise KeyError("ChannelName must be provided by vendor")
 
                 if channel_name == dataset_label:
                     s3_folder_path = utils.dict_query(
@@ -102,10 +103,16 @@ class DatasetStateManager:
                     return "{}/{}.{}".format(
                         s3_folder_path,
                         dataset_label,
-                        filetype
+                        file_type
                     )
 
-        raise ValueError("InputDataConfig is missing, vendor should provide this.")
+        else:
+            raise ValueError("InputDataConfig is missing, vendor should provide this.")
+
+        raise KeyError((
+            "Channel with name = {} was not"
+            "found in vendor solution".format(dataset_label)
+        ))
 
     @staticmethod
     def parse_s3_url(url: str):
@@ -255,7 +262,7 @@ class DatasetStateManager:
             'identifier': self.get_vendor_solution_dataset_identifier(
                 vendor_solution=vendor_solution,
                 dataset_label=dataset['label'],
-                filetype=dataset['datatype']
+                file_type=dataset['file_type']
             )
         })
 
