@@ -275,7 +275,7 @@ class MaintenanceManager:
                 )
 
                 new_solution_base_name = self.query_helper.create_resource_name(
-                    service=self.service.name,
+                    service=self.service.slug,
                     group='training',
                     prefix=[client.name, engine_slug]
                 )
